@@ -20,14 +20,14 @@ import os
 import cPickle
 import re
 from PyQt4 import QtGui
-from PyQt4.QtCore import QStringList, Qt, QSettings, QLocale, QTranslator, QSize
+from PyQt4.QtCore import Qt, QSettings, QLocale, QTranslator, QSize
 from PyQt4.QtCore import pyqtSignal, QModelIndex
 from gayeogi.db.local import Filesystem
 from gayeogi.db.distributor import Distributor
 from gayeogi.interfaces.settings import Settings
 import gayeogi.plugins
 
-version = u'0.6.1'
+version = u'0.6.2'
 locale = QLocale.system().name()
 if sys.platform == 'win32':
     from PyQt4.QtGui import QDesktopServices
@@ -278,23 +278,23 @@ class Main(QtGui.QMainWindow):
         self.ui = Ui_main()
         widget = QtGui.QWidget()
         self.ui.setupUi(widget)
-        self.ui.artists.setHeaderLabels(QStringList([u'Artist']))
+        self.ui.artists.setHeaderLabels([u'Artist'])
         self.ui.artists.itemSelectionChanged.connect(self.fillAlbums)
         delegate = ADRItemDelegate()
         self.ui.artists.setItemDelegateForColumn(0, delegate)
         self.ui.albums = ADRTreeWidget()
-        self.ui.albums.setHeaderLabels(QStringList([u'Year', u'Album']))
+        self.ui.albums.setHeaderLabels([u'Year', u'Album'])
         self.ui.albums.buttonClicked.connect(self.setAnalog)
         self.ui.albums.itemSelectionChanged.connect(self.fillTracks)
         self.ui.verticalLayout_4.addWidget(self.ui.albums)
-        self.ui.tracks.setHeaderLabels(QStringList(['#', u'Title']))
+        self.ui.tracks.setHeaderLabels(['#', u'Title'])
         self.ui.plugins = {}
         self.ui.splitter.restoreState(
                 self.__settings.value(u'splitters').toByteArray())
         self.setCentralWidget(widget)
         self.library = (version, {}, {}, {}, {}, [False])
-        self.ignores = self.__settings.value(u'ignores').toPyObject()
-        if not self.ignores:
+        self.ignores = self.__settings.value(u'ignores', []).toPyObject()
+        if self.ignores == None:
             self.ignores = []
         if not os.path.exists(os.path.join(dbPath, u'db.pkl')):
             dialog = Settings()
@@ -302,27 +302,20 @@ class Main(QtGui.QMainWindow):
         else:
             self.library = self.db.read()
             self.update()
-        directory = unicode(self.__settings.value(u'directory').toPyObject())
+        directory = self.__settings.value(u'directory', []).toPyObject()
+        if type(directory) != list:
+            directory = [(unicode(directory), 2)]
         self.fs = Filesystem(directory, self.library, self.ignores)
         self.fs.stepped.connect(self.statusBar().showMessage)
         self.fs.updated.connect(self.update)
-        self.fs.errors.connect(self.logs)
         self.rt = Distributor(self.library)
         self.rt.stepped.connect(self.statusBar().showMessage)
         self.rt.updated.connect(self.update)
-        self.rt.errors.connect(self.logs)
-        self.ui.logs.setHeaderLabels(QStringList([
-            self.trUtf8('Module'),
-            self.trUtf8('Type'),
-            self.trUtf8('File/Entry'),
-            self.trUtf8('Message')]))
         self.ui.local.clicked.connect(self.local)
         self.ui.remote.clicked.connect(self.remote)
         self.ui.close.clicked.connect(self.close)
         self.ui.save.clicked.connect(self.save)
         self.ui.settings.clicked.connect(self.showSettings)
-        self.ui.clearLogs.clicked.connect(self.ui.logs.clear)
-        self.ui.saveLogs.clicked.connect(self.saveLogs)
         self.ui.artistFilter.textEdited.connect(self.filter_)
         self.ui.albumFilter.textEdited.connect(self.filter_)
         self.ui.trackFilter.textEdited.connect(self.filter_)
@@ -376,8 +369,6 @@ class Main(QtGui.QMainWindow):
                 class__ = class_(self.ui, self.library, self.appendPlugin,
                         self.removePlugin)
                 class__.load()
-                if hasattr(class__, 'errors'):
-                    class__.errors.connect(self.logs)
                 self.ui.plugins[plugin] = class__
             elif not option and class_.loaded:
                 self.ui.plugins[plugin].unload()
@@ -389,6 +380,10 @@ class Main(QtGui.QMainWindow):
                     del self.ui.plugins[plugin]
     def appendPlugin(self, parent, child, position):
         parent = getattr(self.ui, parent)
+        if position == 'start':
+            position = 0
+        elif position == 'end':
+            position = len(parent.parent().children()) - 7
         if isinstance(parent, QtGui.QLayout):
             widget = parent.itemAt(position)
             if not widget:
@@ -397,14 +392,23 @@ class Main(QtGui.QMainWindow):
                 if isinstance(widget, QtGui.QTabWidget):
                     widget.addTab(child, child.name)
                 else:
-                    widget = parent.takeAt(position).widget()
-                    tab = QtGui.QTabWidget()
-                    tab.setTabPosition(tab.South)
-                    tab.addTab(widget, widget.name)
-                    tab.addTab(child, child.name)
-                    parent.insertWidget(position, tab)
+                    try:
+                        widget.name
+                    except AttributeError:
+                        parent.insertWidget(position, child)
+                    else:
+                        widget = parent.takeAt(position).widget()
+                        tab = QtGui.QTabWidget()
+                        tab.setTabPosition(tab.South)
+                        tab.addTab(widget, widget.name)
+                        tab.addTab(child, child.name)
+                        parent.insertWidget(position, tab)
     def removePlugin(self, parent, child, position):
         parent = getattr(self.ui, parent)
+        if position == 'start':
+            position = 0
+        elif position == 'end':
+            position = len(parent.parent().children()) - 8
         if isinstance(parent, QtGui.QLayout):
             widget = parent.itemAt(position).widget()
             try:
@@ -420,16 +424,16 @@ class Main(QtGui.QMainWindow):
                     parent.insertWidget(position, tmp)
                     parent.itemAt(position).widget().show()
     def filter_(self, text):
-        columns = []
-        arguments = []
+        columns = list()
+        arguments = list()
         adr = [u'a', u'd', u'r', u'not a', u'not d', u'not r']
         num_adr = dict()
         __num_adr = {
-                u'a': 123,
-                u'd': 234,
-                u'r': 345
-                }
-        for a in (unicode(text)).split(u'|'):
+            u'a': 123,
+            u'd': 234,
+            u'r': 345
+        }
+        for a in unicode(text).split(u'|'):
             temp = a.split(u':')
             if len(temp) == 1 and temp[0] in adr:
                 temp2 = temp[0].split(u' ')
@@ -442,12 +446,12 @@ class Main(QtGui.QMainWindow):
                 break
             columns.append(temp[0].lower())
             arguments.append(temp[1].lower())
+        tree = self.sender().parent().children()[2]
         if (len(columns) != 0 and len(columns) == len(arguments)) or num_adr:
-            tree = self.sender().parent().children()[2]
             header = tree.header().model()
             num_columns = [i for i in range(tree.columnCount())
-                    if (unicode(header.headerData(i,
-                        Qt.Horizontal).toString())).lower() in columns]
+                if unicode(header.headerData(i,
+                    Qt.Horizontal).toString()).lower() in columns]
             adr_column = -1
             if num_adr:
                 item = tree.topLevelItem(0)
@@ -462,7 +466,7 @@ class Main(QtGui.QMainWindow):
                     try:
                         if item not in hidden:
                             if not re.search(arguments[j],
-                                    (unicode(item.text(c)).lower())):
+                            unicode(item.text(c)).lower()):
                                 item.setHidden(True)
                                 item.setSelected(False)
                                 hidden.append(item)
@@ -479,41 +483,14 @@ class Main(QtGui.QMainWindow):
                             item.setSelected(False)
                             hidden.append(item)
         else:
-            tree = self.sender().parent().children()[2]
             for i in range(tree.topLevelItemCount()):
                 tree.topLevelItem(i).setHidden(False)
-    def saveLogs(self):
-        dialog = QtGui.QFileDialog()
-        filename = dialog.getSaveFileName()
-        if filename:
-            fh = open(filename, u'w')
-            fh.write(self.trUtf8('Database:Type:File/Entry:Message'))
-            for i in range(self.ui.logs.topLevelItemCount()):
-                item = self.ui.logs.topLevelItem(i)
-                for c in range(4):
-                    fh.write(item.text(c))
-                    if c != 3:
-                        fh.write(u':')
-                fh.write(u'\n')
-            fh.close()
-            self.statusBar().showMessage(self.trUtf8('Logs saved'))
-    def logs(self, db, kind, filename, message):
-        if self.__settings.value(u'logs/' + kind).toInt()[0]:
-            item = QtGui.QTreeWidgetItem(QStringList([
-                db,
-                kind,
-                filename,
-                message
-                ]))
-            self.ui.logs.addTopLevelItem(item)
-            self.ui.logs.scrollToItem(item)
-        for i in range(4):
-            self.ui.logs.resizeColumnToContents(i)
     def showSettings(self):
         u"""Show settings dialog and then update accordingly."""
         def __save():
-            directory = unicode(
-                    self.__settings.value(u'directory', u'').toString())
+            directory = self.__settings.value(u'directory', []).toPyObject()
+            if type(directory) != list:
+                directory = [(unicode(directory), 2)]
             self.ignores = self.__settings.value(u'ignores', []).toPyObject()
             self.fs.actualize(directory, self.ignores)
             self.removePluginsTranslators()
@@ -574,7 +551,7 @@ class Main(QtGui.QMainWindow):
         self.ui.artists.clear()
         self.ui.artists.setSortingEnabled(False)
         for i, l in enumerate(self.library[1].keys()):
-            item = QtGui.QTreeWidgetItem(QStringList([l]))
+            item = QtGui.QTreeWidgetItem([l])
             item.setData(0, 123, self.statistics[u'detailed'][l][u'a'])
             item.setData(0, 234, self.statistics[u'detailed'][l][u'd'])
             item.setData(0, 345, self.statistics[u'detailed'][l][u'r'])
@@ -589,12 +566,10 @@ class Main(QtGui.QMainWindow):
             i = self.ui.artists.findItems(a, Qt.MatchExactly)
             if i:
                 i[0].setSelected(True)
-        self.ui.albumFilter.textEdited.emit(self.ui.albumFilter.text())
         for a in sAlbums:
             i = self.ui.albums.findItems(a, Qt.MatchExactly, 1)
             if i:
                 i[0].setSelected(True)
-        self.ui.trackFilter.textEdited.emit(self.ui.trackFilter.text())
         for a in sTracks:
             i = self.ui.tracks.findItems(a, Qt.MatchExactly)
             if i:
@@ -614,7 +589,7 @@ class Main(QtGui.QMainWindow):
             for date, albums in self.library[1][artist].iteritems():
                 for album, data in albums.iteritems():
                     key = self.library[4][artist + date + album]
-                    item_ = QtGui.QTreeWidgetItem(QStringList([date, album]))
+                    item_ = QtGui.QTreeWidgetItem([date, album])
                     item_.artist = artist
                     item_.aIndex = self.ui.artists.indexOfTopLevelItem(item)
                     item_.setData(1, 123, key[u'analog'])
@@ -626,6 +601,7 @@ class Main(QtGui.QMainWindow):
         self.ui.albums.sortItems(0, 0)
         for i in range(4):
             self.ui.albums.resizeColumnToContents(i)
+        self.ui.albumFilter.textEdited.emit(self.ui.albumFilter.text())
     def fillTracks(self):
         items = self.ui.albums.selectedItems()
         self.ui.tracks.clear()
@@ -636,8 +612,7 @@ class Main(QtGui.QMainWindow):
             for num, titles in self.library[1][item.artist] \
                     [date][album].iteritems():
                 for title in titles.keys():
-                    item_ = NumericTreeWidgetItem(QStringList([
-                        num, title]))
+                    item_ = NumericTreeWidgetItem([num, title])
                     item_.album = album
                     item_.year = date
                     item_.artist = item.artist
@@ -646,6 +621,7 @@ class Main(QtGui.QMainWindow):
         self.ui.tracks.sortItems(0, 0)
         self.ui.tracks.resizeColumnToContents(0)
         self.ui.tracks.resizeColumnToContents(1)
+        self.ui.trackFilter.textEdited.emit(self.ui.trackFilter.text())
     def computeStats(self):
         artists = [0, 0, 0]
         albums = [0, 0, 0]
@@ -658,41 +634,29 @@ class Main(QtGui.QMainWindow):
             for y, t in d.iteritems():
                 for al in t.keys():
                     key = self.library[4][a + y + al]
-                    if key[u'analog']:
-                        albums[0] += 1
-                    elif key[u'digital']:
-                        albums[1] += 1
-                    elif key[u'remote']:
-                        albums[2] += 1
-                    if not key[u'analog']:
+                    analog = int(key[u'analog'])
+                    digital = int(key[u'digital'])
+                    remote = int(bool(key[u'remote']))
+                    albums[0] += analog
+                    albums[1] += digital
+                    albums[2] += remote
+                    if not analog:
                         aa = 0
-                    if not key[u'digital']:
+                    if not digital:
                         ad = 0
-                    if not key[u'remote']:
+                    if not remote:
                         ar = 0
-            if aa:
-                artists[0] += 1
-            elif ad:
-                artists[1] += 1
-            elif ar:
-                artists[2] += 1
-            if aa:
-                detailed[a][u'a'] = True
-            else:
-                detailed[a][u'a'] = False
-            if ad:
-                detailed[a][u'd'] = True
-            else:
-                detailed[a][u'd'] = False
-            if ar:
-                detailed[a][u'r'] = True
-            else:
-                detailed[a][u'r'] = False
+            detailed[a][u'a'] = bool(aa)
+            detailed[a][u'd'] = bool(ad)
+            detailed[a][u'r'] = bool(ar)
+            artists[0] += aa
+            artists[1] += ad
+            artists[2] += ar
         self.statistics = {
-                u'artists': artists,
-                u'albums': albums,
-                u'detailed': detailed
-                }
+            u'artists': artists,
+            u'albums': albums,
+            u'detailed': detailed
+        }
     def closeEvent(self, event):
         def unload():
             for plugin in self.ui.plugins.values():
